stringtools.arg_to_bidirectional_direction_string
=================================================

.. autofunction:: abjad.tools.stringtools.arg_to_bidirectional_direction_string.arg_to_bidirectional_direction_string
